This is part of the aika project for time series analyses. These utilities 
contain useful utilties for the project such as session consistent hash functions. It can
be installed as
``pip install aika-utilties`` but it is not really intended for standalone use.